==> ssp-center-api-0.2.69.fangzhipeng-20180821.062634-12-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqChargeHistory.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class ReqChargeHistory extends ReqPageQuery implements Serializable {

    private static final long serialVersionUID = -7913283536431233741L;

    private List<Long>        slotIds;

    private Date              createStartDate;

    private Date              createEndDate;

    private List<Integer>     chargeTypes;

    private List<Integer>     historyTypes;

    private List<Integer>     applyTypes;

    private Integer           normalRange;

    public List<Long> getSlotIds() {
        return slotIds;
    }

    public void setSlotIds(List<Long> slotIds) {
        this.slotIds = slotIds;
    }

    public Date getCreateStartDate() {
        return createStartDate;
    }

    public void setCreateStartDate(Date createStartDate) {
        this.createStartDate = createStartDate;
    }

    public Date getCreateEndDate() {
        return createEndDate;
    }

    public void setCreateEndDate(Date createEndDate) {
        this.createEndDate = createEndDate;
    }

    public List<Integer> getChargeTypes() {
        return chargeTypes;
    }

    public void setChargeTypes(List<Integer> chargeTypes) {
        this.chargeTypes = chargeTypes;
    }

    public List<Integer> getHistoryTypes() {
        return historyTypes;
    }

    public void setHistoryTypes(List<Integer> historyTypes) {
        this.historyTypes = historyTypes;
    }

    public List<Integer> getApplyTypes() {
        return applyTypes;
    }

    public void setApplyTypes(List<Integer> applyTypes) {
        this.applyTypes = applyTypes;
    }

    public Integer getNormalRange() {
        return normalRange;
    }

    public void setNormalRange(Integer normalRange) {
        this.normalRange = normalRange;
    }
}

==> ssp-center-api-0.2.74.fangzhipeng-20180928.030318-19-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqChargeHistory.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;

import java.io.Serializable;
import java.util.Collections;
import java.util.Date;
import java.util.List;

public class ReqChargeHistory extends ReqPageQuery implements Serializable {

    private static final long serialVersionUID = -7913283536431233741L;

    private List<Long>        slotIds;

    private Date              createStartDate;

    private Date              createEndDate;

    private List<Integer>     chargeTypes;

    private List<Integer>     historyTypes;

    private List<Integer>     applyTypes;

    private Integer           normalRange;

    public List<Long> getSlotIds() {
        return slotIds;
    }

    public void setSlotIds(List<Long> slotIds) {
        this.slotIds = slotIds;
    }

    public Date getCreateStartDate() {
        return createStartDate;
    }

    public void setCreateStartDate(Date createStartDate) {
        this.createStartDate = createStartDate;
    }

    public Date getCreateEndDate() {
        return createEndDate;
    }

    public void setCreateEndDate(Date createEndDate) {
        this.createEndDate = createEndDate;
    }

    public List<Integer> getChargeTypes() {
        return chargeTypes;
    }

    public void setChargeTypes(List<Integer> chargeTypes) {
        this.chargeTypes = chargeTypes;
    }

    public List<Integer> getHistoryTypes() {
        return historyTypes;
    }

    public void setHistoryTypes(List<Integer> historyTypes) {
        this.historyTypes = historyTypes;
    }

    public List<Integer> getApplyTypes() {
        return applyTypes;
    }

    public void setApplyTypes(List<Integer> applyTypes) {
        this.applyTypes = applyTypes;
    }

    public Integer getNormalRange() {
        return normalRange;
    }

    public void setNormalRange(Integer normalRange) {
        this.normalRange = normalRange;
    }

    /**
     * 广告IDS
     *
     * @param var1
     * @param var2
     * @return
     */
    public List<Long> getSlotIdsByRetain(List<Long> var1, List<Long> var2){
        List<Long> slotList=Lists.newArrayList();
        if (CollectionUtils.isEmpty(var1) ){
            return slotList;
        }
        if (CollectionUtils.isEmpty(var2)){
            return var1;
        }
        var1.retainAll(var2);
        slotList.addAll(var1);
        return slotList;
    }

}
